Reconstruct 2D functional data from tensor product basis coefficients (raw binding)
Source:R/extendr-wrappers.R
basis2fdata_2d_raw.RdReconstruct 2D functional data from tensor product basis coefficients (raw binding)
R/extendr-wrappers.R
basis2fdata_2d_raw.RdReconstruct 2D functional data from tensor product basis coefficients (raw binding)