Reconstruct 2D functional data from tensor product basis coefficients (low-level)
Source:R/extendr-wrappers.R
basis2fdata_2d_rust.RdReconstruct 2D functional data from tensor product basis coefficients (low-level)
R/extendr-wrappers.R
basis2fdata_2d_rust.RdReconstruct 2D functional data from tensor product basis coefficients (low-level)