Skip to contents

Modified Band Depth (MBD) for 1D functional data MBD(x) = average over pairs (i,j) of the proportion of the domain where x is inside the band This is more robust than BD as it doesn't require complete containment

Usage

depth_mbd_1d(fdataobj, fdataori)