Project 2D functional data to tensor product basis coefficients (raw binding)
Source:R/extendr-wrappers.R
fdata2basis_2d_raw.RdProject 2D functional data to tensor product basis coefficients (raw binding)
R/extendr-wrappers.R
fdata2basis_2d_raw.RdProject 2D functional data to tensor product basis coefficients (raw binding)