Fits a functional linear model using Huber's M-estimation, which provides a smooth compromise between least squares and L1.
Value
An object of class 'fregre.robust'. See fregre.l1.
Fits a functional linear model using Huber's M-estimation, which provides a smooth compromise between least squares and L1.
An object of class 'fregre.robust'. See fregre.l1.