Compute the geometric median (L1 median) of 2D functional data using Weiszfeld's algorithm Data is stored as n x (m1*m2) matrix where each row is a flattened surface
Source:R/extendr-wrappers.R
geometric_median_2d.RdCompute the geometric median (L1 median) of 2D functional data using Weiszfeld's algorithm Data is stored as n x (m1*m2) matrix where each row is a flattened surface