Simpson's rule integration for functional data Integrates each curve over the domain
Source:R/extendr-wrappers.R
int_simpson.RdSimpson's rule integration for functional data Integrates each curve over the domain
R/extendr-wrappers.R
int_simpson.RdSimpson's rule integration for functional data Integrates each curve over the domain