Compute Hausdorff distance for 2D functional data (surfaces)
Source:R/extendr-wrappers.R
metric_hausdorff_2d.RdFor surfaces, each sample is treated as a point cloud in 3D space: (s_i, t_j, f(s_i, t_j)) : for all grid points
R/extendr-wrappers.R
metric_hausdorff_2d.RdFor surfaces, each sample is treated as a point cloud in 3D space: (s_i, t_j, f(s_i, t_j)) : for all grid points