Compute symmetric KL divergence matrix for self-distances (1D) Curves are first normalized to be valid probability distributions
Source:R/extendr-wrappers.R
metric_kl_self_1d.RdCompute symmetric KL divergence matrix for self-distances (1D) Curves are first normalized to be valid probability distributions