Compute Lp distance matrix between two sets of functional data
Source:R/extendr-wrappers.R
metric_lp_1d.RdCompute Lp distance matrix between two sets of functional data
R/extendr-wrappers.R
metric_lp_1d.RdCompute Lp distance matrix between two sets of functional data