Compute Lp distance between two 2D functional data objects (surfaces)
Source:R/extendr-wrappers.R
metric_lp_2d.RdFor 2D functional data, the Lp distance is computed as: d(f, g) = (∫∫ |f(s,t) - g(s,t)|^p ds dt)^(1/p)
R/extendr-wrappers.R
metric_lp_2d.RdFor 2D functional data, the Lp distance is computed as: d(f, g) = (∫∫ |f(s,t) - g(s,t)|^p ds dt)^(1/p)