Displays a dendrogram of the hierarchical clustering. The merge
information is converted to an hclust object for plotting.
Usage
# S3 method for class 'elastic.hclust'
plot(x, ...)Displays a dendrogram of the hierarchical clustering. The merge
information is converted to an hclust object for plotting.
# S3 method for class 'elastic.hclust'
plot(x, ...)