Displays cluster mean curves with member curves in the background, one facet per cluster.
Usage
# S3 method for class 'elastic.kmeans'
plot(x, ...)Displays cluster mean curves with member curves in the background, one facet per cluster.
# S3 method for class 'elastic.kmeans'
plot(x, ...)