Creates a ggplot showing the mean difference curve, simultaneous confidence band, and equivalence margins.
Usage
# S3 method for class 'fequiv.test'
plot(x, ...)Creates a ggplot showing the mean difference curve, simultaneous confidence band, and equivalence margins.
# S3 method for class 'fequiv.test'
plot(x, ...)