Displays the cross-validation error as a function of the regularization parameter lambda, with the optimal value marked.
Usage
# S3 method for class 'lambda.cv'
plot(x, ...)Displays the cross-validation error as a function of the regularization parameter lambda, with the optimal value marked.
# S3 method for class 'lambda.cv'
plot(x, ...)