Displays the shape mean curve with aligned input curves in the background.
Usage
# S3 method for class 'shape.mean'
plot(x, ...)Displays the shape mean curve with aligned input curves in the background.
# S3 method for class 'shape.mean'
plot(x, ...)