Displays the mean warping function with a shaded +/- 2 standard deviation confidence band.
Usage
# S3 method for class 'warp.statistics'
plot(x, ...)Displays the mean warping function with a shaded +/- 2 standard deviation confidence band.
# S3 method for class 'warp.statistics'
plot(x, ...)