Assigns new functional observations to clusters using a fitted GMM.
Usage
# S3 method for class 'cluster.gmm'
predict(object, newdata, new.covariates = NULL, ...)Assigns new functional observations to clusters using a fitted GMM.
# S3 method for class 'cluster.gmm'
predict(object, newdata, new.covariates = NULL, ...)