Matrix Profile for motif discovery and period detection Uses STOMP algorithm for efficient computation
Source:R/extendr-wrappers.R
seasonal_matrix_profile.RdMatrix Profile for motif discovery and period detection Uses STOMP algorithm for efficient computation