Compute the pairwise shape distance matrix for functional data in a specified quotient space.
Usage
shape.distance.matrix(
fdataobj,
quotient = c("reparameterization", "translation", "scale"),
lambda = 0
)Compute the pairwise shape distance matrix for functional data in a specified quotient space.
shape.distance.matrix(
fdataobj,
quotient = c("reparameterization", "translation", "scale"),
lambda = 0
)