Skip to contents

Reparameterizes a curve f by composing it with a warping function gamma: f(gamma(t)).

Usage

srsf.reparameterize(fdataobj, gamma)

Arguments

fdataobj

An fdata object (single curve, first row used).

gamma

Numeric vector of warping function values on the same grid.

Value

An fdata object containing the reparameterized curve.

Examples

# \donttest{
fd <- fdata(matrix(sin(seq(0, pi, length.out = 20)), 1, 20),
            argvals = seq(0, 1, length.out = 20))
gamma <- seq(0, 1, length.out = 20)^2
fd_warped <- srsf.reparameterize(fd, gamma)
# }