Compute the maximum reconstruction error of a warp inversion: \(\max_t |\gamma(\gamma^{-1}(t)) - t|\).
Examples
t <- seq(0, 1, length.out = 50)
gamma <- t^2
warp.inverse.error(gamma, t)
#> [1] 1.110223e-16
Compute the maximum reconstruction error of a warp inversion: \(\max_t |\gamma(\gamma^{-1}(t)) - t|\).
t <- seq(0, 1, length.out = 50)
gamma <- t^2
warp.inverse.error(gamma, t)
#> [1] 1.110223e-16