Band Depth (BD) for 1D functional data BD(x) = proportion of pairs (i,j) where x lies within the band formed by curves i and j A curve lies in the band if at every time point t, min(X_i(t), X_j(t)) <= x(t) <= max(X_i(t), X_j(t))
Source:R/extendr-wrappers.R
depth_bd_1d.RdBand Depth (BD) for 1D functional data BD(x) = proportion of pairs (i,j) where x lies within the band formed by curves i and j A curve lies in the band if at every time point t, min(X_i(t), X_j(t)) <= x(t) <= max(X_i(t), X_j(t))