Kernel Functional Spatial Depth (KFSD) for 1D functional data Implements the RKHS-based formulation matching fda.usc h is treated as the actual bandwidth, matching how fda.usc uses hq2 argvals is used for trapezoidal integration to compute L2 norms
Source:R/extendr-wrappers.R
depth_kfsd_1d.RdKernel Functional Spatial Depth (KFSD) for 1D functional data Implements the RKHS-based formulation matching fda.usc h is treated as the actual bandwidth, matching how fda.usc uses hq2 argvals is used for trapezoidal integration to compute L2 norms