Modified Band Depth (MBD) for 1D functional data MBD(x) = average over pairs (i,j) of the proportion of the domain where x is inside the band This is more robust than BD as it doesn't require complete containment
Source:R/extendr-wrappers.R
depth_mbd_1d.RdModified Band Depth (MBD) for 1D functional data MBD(x) = average over pairs (i,j) of the proportion of the domain where x is inside the band This is more robust than BD as it doesn't require complete containment