Compute the canonical representative of a curve in a quotient space. Depending on the quotient, this factors out reparameterization, translation, and/or scale.
Usage
shape.representative(
f,
argvals = NULL,
quotient = c("reparameterization", "translation", "scale")
)Value
A list with components:
- representative
The canonical representative curve
- representative.srsf
SRSF of the representative
- gamma
Warping function to the representative
- translation
Translation applied (0 for reparameterization-only)
- scale
Scale factor applied (1 for reparameterization-only)