Computes the geodesic distance of a warping function from the identity, measuring how much phase variability the warp introduces.
Examples
t <- seq(0, 1, length.out = 20)
warp.complexity(t^2, t)
#> [1] 0.349855
warp.complexity(t, t) # identity = 0
#> [1] 0